@@ -5,11 +5,12 @@ use warnings;
 use 5.010_001;
 use Carp qw(croak);
 
-use version; our $VERSION = 'v0.3.0';
+use version; our $VERSION = 'v0.3.1';
 
-sub instance { croak 'Must implement in child class!'; }
-
-sub gets { croak 'Must implement in child class!'; }
+sub instance     { croak 'Must implement in child class!'; }
+sub gets         { croak 'Must implement in child class!'; }
+sub get_by_id    { croak 'Must implement in child class!'; }
+sub update_by_id { croak 'Must implement in child class!'; }
 
 1;
 
@@ -28,6 +29,8 @@ B<App::Koyomi::DataSource::Job> - Abstract datasource class for job entity
     # Your implementation goes below
     sub instance { ... }
     sub gets { ... }
+    sub get_by_id { ... }
+    sub update_by_id { ... }
 
 =head1 DESCRIPTION
 
@@ -46,6 +49,14 @@ Probably it's singleton.
 
 Fetch all job data as array.
 
+=item B<get_by_id>
+
+Fetch one job data including job_times data.
+
+=item B<update_by_id>
+
+Update one job data including job_times data.
+
 =back
 
 =head1 SEE ALSO
