@@ -12,7 +12,7 @@ use Log::Minimal env_debug => 'KOYOMI_LOG_DEBUG';
 use Smart::Args;
 use Sys::Hostname;
 
-use version; our $VERSION = 'v0.3.0';
+use version; our $VERSION = 'v0.3.1';
 
 sub consume {
     args(
@@ -52,7 +52,9 @@ sub consume {
         },
         where => +{
             run_date => $semaphore->run_date,
-        });
+        },
+        ctx => $ctx,
+    );
 
     unless ($ret) {
         warnf(q/%s Failed to update semaphore; Probably another process got lock./, $header);
